==> side_menu_v1.6.3.zip: README.md <==
🤙 Nextcloud app / Side menu 🎨
===============================

Side menu allows you to modify the position of the main menu by creating a panel on the left of the interface.
This application is rather suitable for instances that activate a lot of applications.

Comptatible with AppOrder.

* [Installation and upgrade](#user-content-installation-and-upgrade)
* [How to contribute?](#user-content-how-to-contribute)
* [Preview](#user-content-preview)

Installation and upgrade
------------------------

Side menu is availabe from the app store. If you want to install it from source: go to https://gitnet.fr/deblan/side_menu/releases and download the last release (side_menu_vX.Y.Z.zip). Copy the content into `apps`.

```
$ cd /path/to/nextcloud/apps
$ unzip -d side_menu /path/to/side_menu_vX.Y.Z.zip
```

Administrators can edit many settings using the administration page.

Users can disable the menu using the page of personal settings.

Use the shortcut `Ctrl`+`o` to open and to hide the side menu. Use `tab` to navigate.

How to contribute?
------------------

You can report a bug or request a feature by opening an issue: https://gitnet.fr/deblan/side_menu/issues

If you are a developer:

* fork the repository
* install an instance of Nextcloud
* go to `apps/` and clone your repository
* go to `apps/side_menu` and run `npm install`

Build javascripts using `webpack --config ./webpack.js` (add `-w` to build them in real time).

Then commit and create a pull request.

Preview
-------

![](https://upload.deblan.org/u/2020-03/5e81b219.jpg)

![](https://upload.deblan.org/u/2020-03/5e7fab2b.jpg)

![](https://upload.deblan.org/u/2020-05/5eb6b76e.png)

![](https://upload.deblan.org/u/2020-05/5eb6b78a.png)

==> side_menu_v1.7.0.zip: README.md <==
🤙 Nextcloud app / Side menu 🎨
===============================

Side menu allows you to modify the position of the main menu by creating a panel on the left of the interface.
This application is rather suitable for instances that activate a lot of applications.

Comptatible with AppOrder.

* [Installation and upgrade](#installation-and-upgrade)
* [How to contribute?](#how-to-contribute)
* [Preview](#preview)

Installation and upgrade
------------------------

Side menu is availabe from the app store. If you want to install it from source: go to https://gitnet.fr/deblan/side_menu/releases and download the last release (side_menu_vX.Y.Z.zip). Copy the content into `apps`.

```
$ cd /path/to/nextcloud/apps
$ unzip -d side_menu /path/to/side_menu_vX.Y.Z.zip
```

Administrators can edit many settings using the administration page.

Users can disable the menu using the page of personal settings.

Use the shortcut `Ctrl`+`o` to open and to hide the side menu. Use `tab` to navigate.

How to contribute?
------------------

You can report a bug or request a feature by opening an issue: https://gitnet.fr/deblan/side_menu/issues

If you are a developer:

* fork the repository
* install an instance of Nextcloud
* go to `apps/` and clone your repository
* go to `apps/side_menu` and run `npm install`

Build javascripts using `webpack --config ./webpack.js` (add `-w` to build them in real time).

Then commit and create a pull request.

Preview
-------

![](https://upload.deblan.org/u/2020-03/5e81b219.jpg)

![](https://upload.deblan.org/u/2020-03/5e7fab2b.jpg)

![](https://upload.deblan.org/u/2020-05/5eb6b76e.png)

![](https://upload.deblan.org/u/2020-05/5eb6b78a.png)
